"use strict";
/**
 * Copyright (c) 2021 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Material = void 0;
var param_definition_1 = require("./param-definition");
var number_1 = require("./number");
function Material(hex) { return hex; }
exports.Material = Material;
(function (Material) {
    function fromNormalized(metalness, roughness) {
        return (((metalness * 255) << 16) | ((roughness * 255) << 8));
    }
    Material.fromNormalized = fromNormalized;
    function fromObjectNormalized(v) {
        return fromNormalized(v.metalness, v.roughness);
    }
    Material.fromObjectNormalized = fromObjectNormalized;
    function toObjectNormalized(material, fractionDigits) {
        var metalness = (material >> 16 & 255) / 255;
        var roughness = (material >> 8 & 255) / 255;
        return {
            metalness: fractionDigits ? (0, number_1.toFixed)(metalness, fractionDigits) : metalness,
            roughness: fractionDigits ? (0, number_1.toFixed)(roughness, fractionDigits) : roughness
        };
    }
    Material.toObjectNormalized = toObjectNormalized;
    function toArray(material, array, offset) {
        array[offset] = (material >> 16 & 255);
        array[offset + 1] = (material >> 8 & 255);
        return array;
    }
    Material.toArray = toArray;
    function toString(material) {
        var metalness = (material >> 16 & 255) / 255;
        var roughness = (material >> 8 & 255) / 255;
        return "M ".concat(metalness, " | R ").concat(roughness);
    }
    Material.toString = toString;
    function getParam(info) {
        return param_definition_1.ParamDefinition.Converted(function (v) { return toObjectNormalized(v, 2); }, function (v) { return fromObjectNormalized(v); }, param_definition_1.ParamDefinition.Group({
            metalness: param_definition_1.ParamDefinition.Numeric(0, { min: 0, max: 1, step: 0.01 }),
            roughness: param_definition_1.ParamDefinition.Numeric(1, { min: 0, max: 1, step: 0.01 }),
        }, info));
    }
    Material.getParam = getParam;
})(Material = exports.Material || (exports.Material = {}));
//# sourceMappingURL=material.js.map