/**
 * Copyright (c) 2021 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
import { ParamDefinition as PD } from './param-definition';
import { toFixed } from './number';
export function Material(hex) { return hex; }
(function (Material) {
    function fromNormalized(metalness, roughness) {
        return (((metalness * 255) << 16) | ((roughness * 255) << 8));
    }
    Material.fromNormalized = fromNormalized;
    function fromObjectNormalized(v) {
        return fromNormalized(v.metalness, v.roughness);
    }
    Material.fromObjectNormalized = fromObjectNormalized;
    function toObjectNormalized(material, fractionDigits) {
        var metalness = (material >> 16 & 255) / 255;
        var roughness = (material >> 8 & 255) / 255;
        return {
            metalness: fractionDigits ? toFixed(metalness, fractionDigits) : metalness,
            roughness: fractionDigits ? toFixed(roughness, fractionDigits) : roughness
        };
    }
    Material.toObjectNormalized = toObjectNormalized;
    function toArray(material, array, offset) {
        array[offset] = (material >> 16 & 255);
        array[offset + 1] = (material >> 8 & 255);
        return array;
    }
    Material.toArray = toArray;
    function toString(material) {
        var metalness = (material >> 16 & 255) / 255;
        var roughness = (material >> 8 & 255) / 255;
        return "M ".concat(metalness, " | R ").concat(roughness);
    }
    Material.toString = toString;
    function getParam(info) {
        return PD.Converted(function (v) { return toObjectNormalized(v, 2); }, function (v) { return fromObjectNormalized(v); }, PD.Group({
            metalness: PD.Numeric(0, { min: 0, max: 1, step: 0.01 }),
            roughness: PD.Numeric(1, { min: 0, max: 1, step: 0.01 }),
        }, info));
    }
    Material.getParam = getParam;
})(Material || (Material = {}));
//# sourceMappingURL=material.js.map